@@ -2,4 +2,4 @@ if __name__ == '__main__':
     import sys
     import steem.cli
 
-    sys.exit(steem.cli.legacy())
+    sys.exit(steem.cli.legacyentry())
