@@ -134,13 +134,13 @@ class Commit(object):
         return tx.broadcast()
 
     def sign(self, unsigned_trx, wifs=[]):
-        """ Sign a provided transaction witht he provided key(s)
+        """ Sign a provided transaction with the provided key(s)
 
             :param dict unsigned_trx: The transaction to be signed and returned
             :param string wifs: One or many wif keys to use for signing
                 a transaction. If not present, the keys will be loaded
                 from the wallet as defined in "missing_signatures" key
-                of the transactizions.
+                of the transactions.
         """
         tx = TransactionBuilder(
             unsigned_trx,
@@ -897,7 +897,7 @@ class Commit(object):
         # if no values were set by user, claim all outstanding balances on
         # account
         if none(
-                int(first(x.split(' ')))
+                float(first(x.split(' ')))
                 for x in [reward_sbd, reward_steem, reward_vests]):
             a = Account(account)
             reward_steem = a['reward_steem_balance']
